==> dde-launcher_5.0.14.orig.tar.xz: dde-launcher-5.0.14/translations/dde-launcher_lo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="lo" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>ບໍ່ມີຜົນການຊອກຫາ</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>ອີນເຕິແນດ</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>ສົນທະນາ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>ເພງ</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ວີດີໂອ</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>ພາບກຣາບຟິກ</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>ອ໊ອບຟີກ</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>ການອ່ານ</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>ການພັດທະນາ</translation>
    </message>
    <message>
        <source>System</source>
        <translation>ລະບົບ</translation>
    </message>
    <message>
        <source>Games</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>ຍົກເລີກ</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>ຢັ້ງຢືນ</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>ເອົາອອກຈາກແດດທ໊ອບ</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>ຖອນການຕິດຕັ້ງ </translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>ເປີດ</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation>ອີນເຕິແນດ</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>ສົນທະນາ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>ເພງ</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ວີກີໂອ</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>ພາບກຣາບຟິກ</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>ເກມ</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>ອ໊ອບຟີກ</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>ການອ່ານ</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>ການພັດທະນາ</translation>
    </message>
    <message>
        <source>System</source>
        <translation>ລະບົບ</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>ອື່ນໆ</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>ຄອມພີວເຕີ</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>ເພງ</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lock</source>
        <translation>ລ໊ອກ</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>ອອກຈາກລະບົບ</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>ເປີດຄືນ</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>ຢຸດໄວ້</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>ປີດລະບົບ</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>ກັບຄືນ</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>ຄອມພີວເຕີ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>ເພງ</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>ປີດລະບົບ</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>ລ໊ອກ</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>ອອກຈາກລະບົບ</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>ເປີດຄືນ</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>ຢຸດໄວ້</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>ກັບຄືນ</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>ຄອມພີວເຕີ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>ເພງ</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation>ກັບຄືນ</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>ຍົກເລີກ</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>ຢັ້ງຢືນ</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-launcher_5.4.5.orig.tar.xz: dde-launcher-5.4.5/translations/dde-launcher_lo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lo">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>ບໍ່ມີຜົນການຊອກຫາ</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>ອີນເຕິແນດ</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>ສົນທະນາ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>ເພງ</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ວີດີໂອ</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>ພາບກຣາບຟິກ</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>ອ໊ອບຟີກ</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>ການອ່ານ</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>ການພັດທະນາ</translation>
    </message>
    <message>
        <source>System</source>
        <translation>ລະບົບ</translation>
    </message>
    <message>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>ຍົກເລີກ</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>ຢັ້ງຢືນ</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>ເອົາອອກຈາກແດດທ໊ອບ</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>ຖອນການຕິດຕັ້ງ </translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation>ເປີດ</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>ອີນເຕິແນດ</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>ສົນທະນາ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>ເພງ</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>ວີກີໂອ</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>ພາບກຣາບຟິກ</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>ເກມ</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>ອ໊ອບຟີກ</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>ການອ່ານ</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>ການພັດທະນາ</translation>
    </message>
    <message>
        <source>System</source>
        <translation>ລະບົບ</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>ອື່ນໆ</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation type="vanished">ຄອມພີວເຕີ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">ເພງ</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation type="vanished">ລ໊ອກ</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="vanished">ອອກຈາກລະບົບ</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="vanished">ເປີດຄືນ</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="vanished">ຢຸດໄວ້</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="vanished">ປີດລະບົບ</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="vanished">ກັບຄືນ</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>ຄອມພີວເຕີ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>ເພງ</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>ປີດລະບົບ</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>ລ໊ອກ</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>ອອກຈາກລະບົບ</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>ເປີດຄືນ</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>ຢຸດໄວ້</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>ກັບຄືນ</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation type="vanished">ຄອມພີວເຕີ</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">ເພງ</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back</source>
        <translation>ກັບຄືນ</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>ຍົກເລີກ</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>ຢັ້ງຢືນ</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
